import json
import click
from .utils import formatter


@click.command()
@click.argument('path', type=click.Path(exists=True))
@click.option('--sort', '-s', is_flag=True, help="some help for sort")
def main(path, sort):
    with open(path, 'r') as _f:
        click.secho(
            formatter(_f.read(), sort_keys=sort),
            fg='yellow', bold=True
        )


if __name__ == '__main__':
    main()





import json


def formatter(string, sort_keys=True, indent=4):
    # load incoming string into JSON
    loaded_json = json.loads(string)
    # dump as string
    return json.dumps(loaded_json, sort_keys=sort_keys, indent=indent)



from setuptools import setup, find_packages

setup(
    name="demo-jformat",
    version="0.0.3",
    description="Reformats files to stdout",
    install_requires = ["click", "colorama"],
    entry_points="""
    [console_scripts]
    jformat=jformat.main:main
    """,
    author="Alfredo Deza",
    author_email="alfredo@deza.pe",
    packages=find_packages(),
)
